aind\_behavior\_curriculum.curriculum.StageGraph
================================================

.. currentmodule:: aind_behavior_curriculum.curriculum

.. autoclass:: StageGraph
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StageGraph.__init__
      ~StageGraph.add_node
      ~StageGraph.add_transition
      ~StageGraph.construct
      ~StageGraph.copy
      ~StageGraph.dict
      ~StageGraph.from_orm
      ~StageGraph.json
      ~StageGraph.model_construct
      ~StageGraph.model_copy
      ~StageGraph.model_dump
      ~StageGraph.model_dump_json
      ~StageGraph.model_json_schema
      ~StageGraph.model_parametrized_name
      ~StageGraph.model_post_init
      ~StageGraph.model_rebuild
      ~StageGraph.model_validate
      ~StageGraph.model_validate_json
      ~StageGraph.model_validate_strings
      ~StageGraph.parse_file
      ~StageGraph.parse_obj
      ~StageGraph.parse_raw
      ~StageGraph.remove_node
      ~StageGraph.remove_node_transition
      ~StageGraph.schema
      ~StageGraph.schema_json
      ~StageGraph.see_node_transitions
      ~StageGraph.see_nodes
      ~StageGraph.set_transition_priority
      ~StageGraph.update_forward_refs
      ~StageGraph.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~StageGraph.model_computed_fields
      ~StageGraph.model_config
      ~StageGraph.model_extra
      ~StageGraph.model_fields
      ~StageGraph.model_fields_set
      ~StageGraph.nodes
      ~StageGraph.graph
   
   